import { Procedure, ProcedureParams, Router, RouterDef } from '@trpc/server';
import type { RootConfig } from '@trpc/server/dist/core/internals/config';
import { TRPC_ERROR_CODE_KEY } from '@trpc/server/rpc';
import { OpenAPIV3 } from 'openapi-types';
import { ZodIssue } from 'zod';
export declare type OpenApiMethod = 'GET' | 'POST' | 'PATCH' | 'PUT' | 'DELETE';
declare type TRPCMeta = Record<string, unknown>;
export declare type OpenApiMeta<TMeta = TRPCMeta> = TMeta & {
    openapi?: {
        enabled?: boolean;
        method: OpenApiMethod;
        path: `/${string}`;
        summary?: string;
        description?: string;
        protect?: boolean;
        tags?: string[];
        headers?: (OpenAPIV3.ParameterBaseObject & {
            name: string;
            in?: 'header';
        })[];
    };
};
export declare type OpenApiProcedure<TMeta = TRPCMeta> = Procedure<'query' | 'mutation', ProcedureParams<RootConfig<{
    transformer: any;
    errorShape: any;
    ctx: any;
    meta: OpenApiMeta<TMeta>;
}>, any, any, any, any, any, OpenApiMeta<TMeta>>>;
export declare type OpenApiProcedureRecord<TMeta = TRPCMeta> = Record<string, OpenApiProcedure<TMeta>>;
export declare type OpenApiRouter<TMeta = TRPCMeta> = Router<RouterDef<RootConfig<{
    transformer: any;
    errorShape: any;
    ctx: any;
    meta: OpenApiMeta<TMeta>;
}>, any, any>>;
export declare type OpenApiSuccessResponse<D = any> = D;
export declare type OpenApiErrorResponse = {
    message: string;
    code: TRPC_ERROR_CODE_KEY;
    issues?: ZodIssue[];
};
export declare type OpenApiResponse<D = any> = OpenApiSuccessResponse<D> | OpenApiErrorResponse;
export {};
//# sourceMappingURL=types.d.ts.map